==> piwigo-2.1.5.zip: piwigo/plugins/LocalFilesEditor/language/cs_CZ/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// | plugin LocalFilesEditor ,czech lang by webprostor.eu                  |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokální konfigurace';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Šablony';
$lang['locfiledit_onglet_lang'] = 'Jazyky';
$lang['locfiledit_onglet_plug'] = 'Vlastní pluginy';
$lang['locfiledit_cant_save'] = 'Vybraný soubor nelze přepsat.Zkontrolujte jestli je složka "include/" zapisovatelná (chmod).';
$lang['locfiledit_newfile'] = 'Soubor neexistuje a bude vytvořen LocalFiles Editorem';
$lang['locfiledit_save_config'] = 'Soubor byl změněn.';
$lang['locfiledit_show_default'] = 'Zobraz referenční soubor: ';
$lang['locfiledit_save_bak'] = 'Záloha bude vytvořena při uložení.';
$lang['locfiledit_saved_bak'] = 'Záloha vytvořena (%s)';
$lang['locfiledit_save_file'] = 'Uložit soubor';
$lang['locfiledit_choose_file'] = 'Vyber soubor k editaci';
$lang['locfiledit_edit'] = 'Editace';
$lang['locfiledit_restore'] = 'Obnovit ze zálohy';
$lang['locfiledit_restore_confirm'] = 'Prosím potvrďte?Obnova nebude mít efekt do dalšího uložení.';
$lang['locfiledit_bak_loaded1'] = 'Záložní soubor nahrán.';
$lang['locfiledit_bak_loaded2'] = 'Musíte nejprve soubor uložit aby mohl být obnoven.';
$lang['locfiledit_syntax_error'] = 'Syntax error! Soubor nemůže být uložen.';
$lang['locfiledit_enable_editarea'] = 'Povol editaci';
$lang['locfiledit_disable_editarea'] = 'Zakázat editaci';
$lang['locfiledit_new_tpl'] = 'Vytvořit nový soubor';
$lang['locfiledit_new_filename'] = 'Název souboru';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Prázdná stránka';
$lang['locfiledit_parent_directory'] = 'Nadřazená složka';
$lang['locfiledit_filename_error'] = 'Nepovolené znaky v názvu souboru.';
$lang['locfiledit_file_already_exists'] = 'Soubor už existuje.';
$lang['locfiledit_model_error'] = 'Musíte zvolit model.';
$lang['locfiledit_empty_filename'] = 'Musíte vyplnit název souboru.';
$lang['locfiledit_webmaster_only'] = 'Pouze webmaster může vytvářet nebo měnit lokální soubory.';

?>

==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/cs_CZ/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// | plugin LocalFilesEditor ,czech lang by webprostor.eu                  |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Lokální konfigurace';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Šablony';
$lang['locfiledit_onglet_lang'] = 'Jazyky';
$lang['locfiledit_onglet_plug'] = 'Vlastní pluginy';
$lang['locfiledit_cant_save'] = 'Vybraný soubor nelze přepsat.Zkontrolujte jestli je složka "local/" zapisovatelná (chmod).';
$lang['locfiledit_newfile'] = 'Soubor neexistuje a bude vytvořen LocalFiles Editorem';
$lang['locfiledit_save_config'] = 'Soubor byl změněn.';
$lang['locfiledit_show_default'] = 'Zobraz referenční soubor: ';
$lang['locfiledit_save_bak'] = 'Záloha bude vytvořena při uložení.';
$lang['locfiledit_saved_bak'] = 'Záloha vytvořena (%s)';
$lang['locfiledit_save_file'] = 'Uložit soubor';
$lang['locfiledit_choose_file'] = 'Vyber soubor k editaci';
$lang['locfiledit_edit'] = 'Editace';
$lang['locfiledit_restore'] = 'Obnovit ze zálohy';
$lang['locfiledit_restore_confirm'] = 'Prosím potvrďte?Obnova nebude mít efekt do dalšího uložení.';
$lang['locfiledit_bak_loaded1'] = 'Záložní soubor nahrán.';
$lang['locfiledit_bak_loaded2'] = 'Musíte nejprve soubor uložit aby mohl být obnoven.';
$lang['locfiledit_syntax_error'] = 'Syntax error! Soubor nemůže být uložen.';
$lang['locfiledit_enable_editarea'] = 'Povol editaci';
$lang['locfiledit_disable_editarea'] = 'Zakázat editaci';
$lang['locfiledit_new_tpl'] = 'Vytvořit nový soubor';
$lang['locfiledit_new_filename'] = 'Název souboru';
$lang['locfiledit_model'] = 'Model';
$lang['locfiledit_empty_page'] = 'Prázdná stránka';
$lang['locfiledit_parent_directory'] = 'Nadřazená složka';
$lang['locfiledit_filename_error'] = 'Nepovolené znaky v názvu souboru.';
$lang['locfiledit_file_already_exists'] = 'Soubor už existuje.';
$lang['locfiledit_model_error'] = 'Musíte zvolit model.';
$lang['locfiledit_empty_filename'] = 'Musíte vyplnit název souboru.';
$lang['locfiledit_webmaster_only'] = 'Pouze webmaster může vytvářet nebo měnit lokální soubory.';

?>
